@@ -58,6 +58,9 @@ def load_openjpeg(libopenjpeg_path):
                                 'bin', 'openjpeg.dll')
             if os.path.exists(path):
                 libopenjpeg_path = path
+        else:
+            # No sense trying further on Linux
+            return None
 
     try:
         if os.name == "nt":
@@ -124,6 +127,10 @@ def glymur_config():
     libs = read_config_file()
     libopenjp2_handle = load_openjp2(libs['openjp2'])
     libopenjpeg_handle = load_openjpeg(libs['openjpeg'])
+    if libopenjp2_handle is None and libopenjpeg_handle is None:
+        msg = "Neither the openjp2 nor the openjpeg library could be loaded.  "
+        msg += "Operating in severely degraded mode."
+        warnings.warn(msg, UserWarning)
     return libopenjp2_handle, libopenjpeg_handle
 
 
